@@ -10,7 +10,5 @@ if [ -z $DESTDIR ]; then
 	glib-compile-schemas "$PREFIX/share/glib-2.0/schemas"
 	echo 'Updating desktop database'
 	update-desktop-database -q
-	echo 'Updating icon cache'
-	gtk-update-icon-cache -q -t -f "$PREFIX/share/icons/hicolor"
 
 fi
\ No newline at end of file
